@@ -14,7 +14,8 @@ class ClientPopulationConfig:
                  client_manager_log_dir: str, client_manager_max_workers: int,
                  num_commands: int = 5,
                  client_time_step_len_seconds: int = 1, time_scaling_factor: float = 0.01,
-                 period_scaling_factor: float = 20, docker_gw_bridge_ip: str = "", physical_host_ip: str = ""):
+                 period_scaling_factor: float = 20, docker_gw_bridge_ip: str = "", physical_host_ip: str = "",
+                 exponents = None, factors = None, breakpoints = None, breakvalues = None):
         """
         Creates a ClientPopulationConfig DTO Object
 
@@ -31,6 +32,10 @@ class ClientPopulationConfig:
         :param client_manager_max_workers: the maximum number of GRPC workers for the client manager
         :param docker_gw_bridge_ip: IP to reach the container from the host network
         :param physical_host_ip: IP of the physical host where the container is running
+        :param exponents: exponents for spike-moduldated arrival process
+        :param factors: factors for spike-moduldated arrival process
+        :param breakpoints: breakpoints for piece-wise constant arrival process
+        :param breakvalues: breakvalues for piece-wise constant arrival process
         """
         self.networks = networks
         self.ip = ip
@@ -47,6 +52,10 @@ class ClientPopulationConfig:
         self.client_manager_max_workers = client_manager_max_workers
         self.docker_gw_bridge_ip = docker_gw_bridge_ip
         self.physical_host_ip = physical_host_ip
+        self.exponents = exponents
+        self.factors = factors
+        self.breakpoints = breakpoints
+        self.breakvalues = breakvalues
 
     @staticmethod
     def from_dict(d: Dict[str, Any]) -> "ClientPopulationConfig":
@@ -65,7 +74,9 @@ class ClientPopulationConfig:
             period_scaling_factor=d["period_scaling_factor"], time_scaling_factor=d["time_scaling_factor"],
             client_manager_log_dir=d["client_manager_log_dir"], client_manager_log_file=d["client_manager_log_file"],
             client_manager_max_workers=d["client_manager_max_workers"],
-            docker_gw_bridge_ip=d["docker_gw_bridge_ip"], physical_host_ip=d["physical_host_ip"]
+            docker_gw_bridge_ip=d["docker_gw_bridge_ip"], physical_host_ip=d["physical_host_ip"],
+            exponents = d["exponents"],  factors=d["factors"], breakpoints=d["breakpoints"],
+            breakvalues=d["breakvalues"]
         )
         return obj
 
@@ -81,7 +92,8 @@ class ClientPopulationConfig:
             num_commands=0, client_time_step_len_seconds=self.client_time_step_len_seconds,
             period_scaling_factor=self.period_scaling_factor, time_scaling_factor=self.time_scaling_factor,
             client_manager_log_file="client_manager.log", client_manager_log_dir="/", client_manager_max_workers=10,
-            docker_gw_bridge_ip=self.docker_gw_bridge_ip, physical_host_ip=self.physical_host_ip
+            docker_gw_bridge_ip=self.docker_gw_bridge_ip, physical_host_ip=self.physical_host_ip,
+            breakpoints=self.breakpoints, breakvalues=self.breakvalues, exponents=self.exponents, factors=self.factors
         )
 
     def to_dict(self) -> Dict[str, Any]:
@@ -104,6 +116,10 @@ class ClientPopulationConfig:
         d["client_manager_max_workers"] = self.client_manager_max_workers
         d["docker_gw_bridge_ip"] = self.docker_gw_bridge_ip
         d["physical_host_ip"] = self.physical_host_ip
+        d["exponents"] = self.exponents
+        d["factors"] = self.factors
+        d["breakpoints"] = self.breakpoints
+        d["breakvalues"] = self.breakvalues
         return d
 
     def __str__(self) -> str:
@@ -119,7 +135,9 @@ class ClientPopulationConfig:
                f"client_manager_log_file: {self.client_manager_log_file}, " \
                f"client_manager_log_dir: {self.client_manager_log_dir}, " \
                f"client_manager_max_workers: {self.client_manager_max_workers}, " \
-               f"docker_gw_bridge_ip:{self.docker_gw_bridge_ip}, physical_host_ip: {self.physical_host_ip}"
+               f"docker_gw_bridge_ip:{self.docker_gw_bridge_ip}, physical_host_ip: {self.physical_host_ip}, " \
+               f"exponents: {self.exponents}, factors: {self.factors}, breakpoints: {self.breakpoints}, " \
+               f"breakvalues: {self.breakvalues}"
 
     def to_json_str(self) -> str:
         """
